wlan: Fix to set BSSID in the action frame to AP MAC address

outgoing vendor specific action frame BSSID set to STA MAC
address incorrectly. Fix is to change this to AP BSSID

Change-Id: I956d46c291afcb93a9cab32061b17b12964d1d45
CRs-Fixed: 469450
diff --git a/CORE/HDD/src/wlan_hdd_main.c b/CORE/HDD/src/wlan_hdd_main.c
index 0f88ce0..a6dd988 100644
--- a/CORE/HDD/src/wlan_hdd_main.c
+++ b/CORE/HDD/src/wlan_hdd_main.c
@@ -1332,11 +1332,11 @@
            /* Fill destination address (bssid of the AP) */
            vos_mem_copy(finalBuf + 4, targetApBssid, sizeof(targetApBssid));
 
-           /* Fill BSSID (STA mac address) */
+           /* Fill source address (STA mac address) */
            vos_mem_copy(finalBuf + 10, pAdapter->macAddressCurrent.bytes, sizeof(pAdapter->macAddressCurrent.bytes));
 
-           /* Fill source address (STA mac address) */
-           vos_mem_copy(finalBuf + 16, pAdapter->macAddressCurrent.bytes, sizeof(pAdapter->macAddressCurrent.bytes));
+           /* Fill BSSID (AP mac address) */
+           vos_mem_copy(finalBuf + 16, targetApBssid, sizeof(targetApBssid));
 
            /* Fill received buffer from 24th address */
            vos_mem_copy(finalBuf + 24, buf, bufLen);